<?php

return [
    'number.decimals_separator' => ',',
    'number.thousands_separator' => ' ',
    'None' => 'Ingen',
    'Edit' => 'Redigera',
    'Remove' => 'Ta bort',
    'Yes' => 'Ja',
    'No' => 'Nej',
    'cancel' => 'avbryt',
    'or' => 'eller',
    'Yellow' => 'Gul',
    'Blue' => 'Blå',
    'Green' => 'Grön',
    'Purple' => 'Lila',
    'Red' => 'Röd',
    'Orange' => 'Orange',
    'Grey' => 'Grå',
    'Brown' => 'Brun',
    'Deep Orange' => 'Mörkorange',
    'Dark Grey' => 'Mörkgrå',
    'Pink' => 'Rosa',
    'Teal' => 'Grönblå',
    'Cyan' => 'Cyan',
    'Lime' => 'Lime',
    'Light Green' => 'Ljusgrön',
    'Amber' => 'Bärnsten',
    'Save' => 'Spara',
    'Login' => 'Login',
    'Official website:' => 'Officiell webbsida:',
    'Unassigned' => 'Ej tilldelad',
    'View this task' => 'Se denna uppgift',
    'Remove user' => 'Ta bort användare',
    'Do you really want to remove this user: "%s"?' => 'Vill du verkligen ta bort användaren: "%s"?',
    'All users' => 'Alla användare',
    'Username' => 'Användarnamn',
    'Password' => 'Lösenord',
    'Administrator' => 'Administratör',
    'Sign in' => 'Logga in',
    'Users' => 'Användare',
    'Forbidden' => 'Ej tillåten',
    'Access Forbidden' => 'Ej tillåten',
    'Edit user' => 'Ändra användare',
    'Logout' => 'Logga ut',
    'Bad username or password' => 'Fel användarnamn eller lösenord',
    'Edit project' => 'Ändra projekt',
    'Name' => 'Namn',
    'Projects' => 'Projekt',
    'No project' => 'Inget projekt',
    'Project' => 'Projekt',
    'Status' => 'Status',
    'Tasks' => 'Uppgifter',
    'Board' => 'Tavla',
    'Actions' => 'Åtgärder',
    'Inactive' => 'Inaktiv',
    'Active' => 'Aktiv',
    'Unable to update this board.' => 'Kunde inte uppdatera tavlan',
    'Disable' => 'Inaktivera',
    'Enable' => 'Aktivera',
    'New project' => 'Nytt projekt',
    'Do you really want to remove this project: "%s"?' => 'Vill du verkligen ta bort projektet: "%s" ?',
    'Remove project' => 'Ta bort projekt',
    'Edit the board for "%s"' => 'Ändra tavlan för "%s"',
    'Add a new column' => 'Lägg till ny kolumn',
    'Title' => 'Titel',
    'Assigned to %s' => 'Tilldelad %s',
    'Remove a column' => 'Ta bort en kolumn',
    'Unable to remove this column.' => 'Kunde inte ta bort kolumnen.',
    'Do you really want to remove this column: "%s"?' => 'Vill du verkligen ta bort kolumnen: "%s"?',
    'Settings' => 'Inställningar',
    'Application settings' => 'Applikationsinställningar',
    'Language' => 'Språk',
    'Webhook token:' => 'Token för webhooks:',
    'API token:' => 'API token:',
    'Database size:' => 'Databasstorlek:',
    'Download the database' => 'Ladda ner databasen',
    'Optimize the database' => 'Optimera databasen',
    '(VACUUM command)' => '(Vacuum-kommando)',
    '(Gzip compressed Sqlite file)' => '(Gzip-komprimera Sqlite-filen)',
    'Close a task' => 'Stäng en uppgift',
    'Column' => 'Kolumn',
    'Color' => 'Färg',
    'Assignee' => 'Uppdragsinnehavare',
    'Create another task' => 'Skapa ännu en uppgift',
    'New task' => 'Ny uppgift',
    'Open a task' => 'Öppna en uppgift',
    'Do you really want to open this task: "%s"?' => 'Vill du verkligen öppna denna uppgift: "%s"?',
    'Back to the board' => 'Tillbaka till tavlan',
    'There is nobody assigned' => 'Det finns ingen tilldelad',
    'Column on the board:' => 'Kolumn på tavlan:',
    'Close this task' => 'Stäng uppgiften',
    'Open this task' => 'Öppna uppgiften',
    'There is no description.' => 'Det finns ingen beskrivning.',
    'Add a new task' => 'Lägg till en ny uppgift',
    'The username is required' => 'Användarnamnet måste anges',
    'The maximum length is %d characters' => 'Max antal bokstäver är %d',
    'The minimum length is %d characters' => 'Minst antal bokstäver är %d',
    'The password is required' => 'Lösenordet måste anges.',
    'This value must be an integer' => 'Värdet måste vara ett heltal.',
    'The username must be unique' => 'Användarnamnet måste vara unikt',
    'The user id is required' => 'Användar-ID måste anges',
    'Passwords don\'t match' => 'Lösenorden matchar inte',
    'The confirmation is required' => 'Bekräftelse behövs.',
    'The project is required' => 'Projektet måste anges',
    'The id is required' => 'Aktuellt ID måste anges',
    'The project id is required' => 'Projekt-ID måste anges',
    'The project name is required' => 'Ett projektnamn måste anges',
    'The title is required' => 'En titel måste anges.',
    'Settings saved successfully.' => 'Inställningarna har sparats.',
    'Unable to save your settings.' => 'Kunde inte spara dina ändringar',
    'Database optimization done.' => 'Databasen har optimerats.',
    'Your project has been created successfully.' => 'Ditt projekt har skapats.',
    'Unable to create your project.' => 'Kunde inte skapa ditt projekt.',
    'Project updated successfully.' => 'Projektet har uppdaterats.',
    'Unable to update this project.' => 'Kunde inte uppdatera detta projekt.',
    'Unable to remove this project.' => 'Kunde inte ta bort detta projekt.',
    'Project removed successfully.' => 'Projektet har tagits bort.',
    'Project activated successfully.' => 'Projektet har aktiverats.',
    'Unable to activate this project.' => 'Kunde inte aktivera detta projekt.',
    'Project disabled successfully.' => 'Projektet har inaktiverats.',
    'Unable to disable this project.' => 'Kunde inte inaktivera detta projekt.',
    'Unable to open this task.' => 'Kunde inte öppna denna uppgift.',
    'Task opened successfully.' => 'Uppgiften har öppnats.',
    'Unable to close this task.' => 'Kunde inte stänga denna uppgift.',
    'Task closed successfully.' => 'Uppgiften har stängts.',
    'Unable to update your task.' => 'Kunde inte uppdatera din uppgift.',
    'Task updated successfully.' => 'Uppgiften har uppdaterats.',
    'Unable to create your task.' => 'Kunde inte skapa din uppgift.',
    'Task created successfully.' => 'Uppgiften har skapats.',
    'User created successfully.' => 'Användaren har skapats.',
    'Unable to create your user.' => 'Kunde inte skapa din användare.',
    'User updated successfully.' => 'Användaren har updaterats.',
    'User removed successfully.' => 'Användaren har tagits bort.',
    'Unable to remove this user.' => 'Kunde inte ta bort denna användare.',
    'Board updated successfully.' => 'Tavlan uppdaterad.',
    'Ready' => 'Denna månad',
    'Backlog' => 'Att göra',
    'Work in progress' => 'Pågående',
    'Done' => 'Slutfört',
    'Application version:' => 'Version:',
    'Id' => 'ID',
    'Public link' => 'Publik länk',
    'Timezone' => 'Tidszon',
    'Sorry, I didn\'t find this information in my database!' => 'Informationen kunde inte hittas i databasen.',
    'Page not found' => 'Sidan hittas inte',
    'Complexity' => 'Komplexitet',
    'Task limit' => 'Uppgiftsbegränsning',
    'Task count' => 'Antal uppgifter',
    'User' => 'Användare',
    'Comments' => 'Kommentarer',
    'Comment is required' => 'En kommentar måste lämnas',
    'Comment added successfully.' => 'Kommentaren har lagts till.',
    'Unable to create your comment.' => 'Kommentaren kunde inte laddas upp.',
    'Due Date' => 'Måldatum',
    'Invalid date' => 'Ej tillåtet datum',
    'Automatic actions' => 'Automatiska åtgärder',
    'Your automatic action has been created successfully.' => 'Din automatiska åtgärd har skapats.',
    'Unable to create your automatic action.' => 'Kunde inte skapa din automatiska åtgärd.',
    'Remove an action' => 'Ta bort en åtgärd',
    'Unable to remove this action.' => 'Kunde inte ta bort denna åtgärd.',
    'Action removed successfully.' => 'Åtgärden har tagits bort.',
    'Automatic actions for the project "%s"' => 'Automatiska åtgärder för projektet "%s"',
    'Add an action' => 'Lägg till en åtgärd',
    'Event name' => 'Händelsenamn',
    'Action' => 'Åtgärd',
    'Event' => 'Händelse',
    'When the selected event occurs execute the corresponding action.' => 'När händelsen inträffar, kör inställd åtgärd.',
    'Next step' => 'Nästa steg',
    'Define action parameters' => 'Definiera händelseparametrar',
    'Do you really want to remove this action: "%s"?' => 'Vill du verkligen ta bort denna åtgärd: "%s"?',
    'Remove an automatic action' => 'Ta bort en automatiskt åtgärd',
    'Assign the task to a specific user' => 'Tilldela uppgiften till en viss användare',
    'Assign the task to the person who does the action' => 'Tilldela uppgiften till personen som skapar den',
    'Duplicate the task to another project' => 'Kopiera uppgiften till ett annat projekt',
    'Move a task to another column' => 'Flytta en uppgift till en annan kolumn',
    'Task modification' => 'Ändra uppgift',
    'Task creation' => 'Skapa uppgift',
    'Closing a task' => 'Stänger en uppgift',
    'Assign a color to a specific user' => 'Tilldela en färg till en viss användare',
    'Position' => 'Position',
    'Duplicate to project' => 'Kopiera till ett annat projekt',
    'Duplicate' => 'Kopiera uppgiften',
    'Link' => 'Länk',
    'Comment updated successfully.' => 'Kommentaren har uppdaterats.',
    'Unable to update your comment.' => 'Kunde inte uppdatera din kommentar.',
    'Remove a comment' => 'Ta bort en kommentar',
    'Comment removed successfully.' => 'Kommentaren har tagits bort.',
    'Unable to remove this comment.' => 'Kunde inte ta bort denna kommentar.',
    'Do you really want to remove this comment?' => 'Är du säker på att du vill ta bort denna kommentar?',
    'Current password for the user "%s"' => 'Nuvarande lösenord för användaren "%s"',
    'The current password is required' => 'Nuvarande lösenord måste anges',
    'Wrong password' => 'Fel lösenord',
    'Unknown' => 'Okänd',
    'Last logins' => 'Senaste inloggningarna',
    'Login date' => 'Inloggningsdatum',
    'Authentication method' => 'Autentiseringsmetod',
    'IP address' => 'IP-adress',
    'User agent' => 'Användaragent/webbläsare',
    'Persistent connections' => 'Beständiga anslutningar',
    'No session.' => 'Ingen session.',
    'Expiration date' => 'Förfallodatum',
    'Remember Me' => 'Kom ihåg mig',
    'Creation date' => 'Skapandedatum',
    'Everybody' => 'Alla',
    'Open' => 'Öppen',
    'Closed' => 'Stängd',
    'Search' => 'Sök',
    'Nothing found.' => 'Inget kunde hittas.',
    'Due date' => 'Måldatum',
    'Description' => 'Beskrivning',
    '%d comments' => '%d kommentarer',
    '%d comment' => '%d kommentar',
    'Email address invalid' => 'Epost-adressen ogiltig',
    'Your external account is not linked anymore to your profile.' => 'Ditt externa konto är inte längre länkat till din profil.',
    'Unable to unlink your external account.' => 'Kunde inte koppla från ditt externa konto.',
    'External authentication failed' => 'Extern autentisering misslyckades',
    'Your external account is linked to your profile successfully.' => 'Ditt externa konto länkades till din profil.',
    'Email' => 'Epost',
    'Task removed successfully.' => 'Uppgiften har tagits bort.',
    'Unable to remove this task.' => 'Kunde inte ta bort denna uppgift.',
    'Remove a task' => 'Ta bort en uppgift',
    'Do you really want to remove this task: "%s"?' => 'Vill du verkligen ta bort denna uppgift: "%s"?',
    'Assign automatically a color based on a category' => 'Tilldela automatiskt en färg baserat på en kategori',
    'Assign automatically a category based on a color' => 'Tilldela automatiskt en kategori baserat på en färg',
    'Task creation or modification' => 'Skapa eller ändra uppgift',
    'Category' => 'Kategori',
    'Category:' => 'Kategori:',
    'Categories' => 'Ange kategorier',
    'Your category has been created successfully.' => 'Din kategori har skapats.',
    'This category has been updated successfully.' => 'Din kategori har uppdaterats.',
    'Unable to update this category.' => 'Kunde inte uppdatera din kategori.',
    'Remove a category' => 'Ta bort en kategori',
    'Category removed successfully.' => 'Kategorin har tagits bort.',
    'Unable to remove this category.' => 'Kunde inte ta bort denna kategori.',
    'Category modification for the project "%s"' => 'Ändring av kategori för projektet "%s"',
    'Category Name' => 'Kategorinamn',
    'Add a new category' => 'Lägg till en kategori',
    'Do you really want to remove this category: "%s"?' => 'Vill du verkligen ta bort denna kategori: "%s"?',
    'All categories' => 'Alla kategorier',
    'No category' => 'Ingen kategori',
    'The name is required' => 'Namnet måste anges',
    'Remove a file' => 'Ta bort en fil',
    'Unable to remove this file.' => 'Kunde inte ta bort denna fil.',
    'File removed successfully.' => 'Filen har tagits bort.',
    'Attach a document' => 'Bifoga ett dokument',
    'Do you really want to remove this file: "%s"?' => 'Vill du verkligen ta bort denna fil: "%s"?',
    'Attachments' => 'Bifogade filer',
    'Edit the task' => 'Ändra uppgiften',
    'Add a comment' => 'Lägg till kommentar',
    'Edit a comment' => 'Ändra en kommentar',
    'Summary' => 'Sammanfattning',
    'Time tracking' => 'Tidsåtgång',
    'Estimate:' => 'Uppskattning',
    'Spent:' => 'Nedlagd tid',
    'Do you really want to remove this sub-task?' => 'Vill du verkligen ta bort deluppgiften?',
    'Remaining:' => 'Återstående:',
    'hours' => 'timmar',
    'estimated' => 'uppskattat',
    'Sub-Tasks' => 'Deluppgifter',
    'Add a sub-task' => 'Lägg till deluppgift',
    'Original estimate' => 'Ursprunglig uppskattning',
    'Create another sub-task' => 'Skapa en till deluppgift',
    'Time spent' => 'Nedlagd tid',
    'Edit a sub-task' => 'Ändra en deluppgift',
    'Remove a sub-task' => 'Ta bort en deluppgift',
    'The time must be a numeric value' => 'Tiden måste ha ett numeriskt värde',
    'Todo' => 'Att göra',
    'In progress' => 'Pågående',
    'Sub-task removed successfully.' => 'Deluppgiften har tagits bort.',
    'Unable to remove this sub-task.' => 'Kunde inte ta bort denna deluppgift.',
    'Sub-task updated successfully.' => 'Deluppgiften har uppdaterats.',
    'Unable to update your sub-task.' => 'Kunde inte uppdatera din deluppgift.',
    'Unable to create your sub-task.' => 'Kunde inte skapa din deluppgift.',
    'Maximum size: ' => 'Maxstorlek: ',
    'Display another project' => 'Visa ett annat projekt',
    'Created by %s' => 'Skapad av %s',
    'Tasks Export' => 'Exportera uppgifter',
    'Start Date' => 'Startdatum',
    'Execute' => 'Utför',
    'Task Id' => 'Uppgift-ID',
    'Creator' => 'Skapare',
    'Modification date' => 'Ändringsdatum',
    'Completion date' => 'Slutfört datum',
    'Clone' => 'Klona',
    'Project cloned successfully.' => 'Projektet har klonats.',
    'Unable to clone this project.' => 'Kunde inte klona projektet.',
    'Enable email notifications' => 'Aktivera e-postnotiser',
    'Task position:' => 'Uppgiftsposition:',
    'The task #%d has been opened.' => 'Uppgiften #%d har öppnats.',
    'The task #%d has been closed.' => 'Uppgiften #%d har stängts.',
    'Sub-task updated' => 'Deluppgift uppdaterad',
    'Title:' => 'Titel:',
    'Status:' => 'Status:',
    'Assignee:' => 'Tilldelad:',
    'Time tracking:' => 'Tidsspårning',
    'New sub-task' => 'Ny deluppgift',
    'New attachment added "%s"' => 'Ny bifogning tillagd "%s"',
    'New comment posted by %s' => 'Ny kommentar postad av %s',
    'New comment' => 'Ny kommentar',
    'Comment updated' => 'Kommentaren har uppdaterats',
    'New subtask' => 'Ny deluppgift',
    'I only want to receive notifications for these projects:' => 'Jag vill endast få notiser för dessa projekt:',
    'view the task on Kanboard' => 'Visa uppgiften på Kanboard',
    'Public access' => 'Publik åtkomst',
    'Disable public access' => 'Inaktivera publik åtkomst',
    'Enable public access' => 'Aktivera publik åtkomst',
    'Public access disabled' => 'Publik åtkomst har inaktiverats',
    'Move the task to another project' => 'Flytta uppgiften till ett annat projekt',
    'Move to project' => 'Flytta till ett annat projekt',
    'Do you really want to duplicate this task?' => 'Vill du verkligen kopiera denna uppgift?',
    'Duplicate a task' => 'Kopiera en uppgift',
    'External accounts' => 'Externa konton',
    'Account type' => 'Kontotyp',
    'Local' => 'Lokal',
    'Remote' => 'Fjärr',
    'Enabled' => 'Aktiverad',
    'Disabled' => 'Inaktiverad',
    'Login:' => 'Användarnam:',
    'Full Name:' => 'Namn:',
    'Email:' => 'E-post:',
    'Notifications:' => 'Notiser:',
    'Notifications' => 'Notiser',
    'Account type:' => 'Kontotyp:',
    'Edit profile' => 'Ändra profil',
    'Change password' => 'Byt lösenord',
    'Password modification' => 'Ändra lösenord',
    'External authentications' => 'Extern autentisering',
    'Never connected.' => 'Inte ansluten.',
    'No external authentication enabled.' => 'Ingen extern autentisering aktiverad.',
    'Password modified successfully.' => 'Lösenordet har ändrats.',
    'Unable to change the password.' => 'Kunde inte byta lösenord.',
    'Change category' => 'Byt kategori',
    '%s updated the task %s' => '%s uppdaterade uppgiften %s',
    '%s opened the task %s' => '%s öppna uppgiften %s',
    '%s moved the task %s to the position #%d in the column "%s"' => '%s flyttade uppgiften %s till positionen #%d i kolumnen "%s"',
    '%s moved the task %s to the column "%s"' => '%s flyttade uppgiften %s till kolumnen "%s"',
    '%s created the task %s' => '%s skapade uppgiften %s',
    '%s closed the task %s' => '%s stängde uppgiften %s',
    '%s created a subtask for the task %s' => '%s skapade en deluppgift för uppgiften %s',
    '%s updated a subtask for the task %s' => '%s uppdaterade en deluppgift för uppgiften %s',
    'Assigned to %s with an estimate of %s/%sh' => 'Tilldelades %s med en uppskattning på %s/%sh',
    'Not assigned, estimate of %sh' => 'Inte tilldelade, uppskattat %sh',
    '%s updated a comment on the task %s' => '%s uppdaterade en kommentar till uppgiften %s',
    '%s commented the task %s' => '%s kommenterade uppgiften %s',
    '%s\'s activity' => '%ss aktivitet',
    'RSS feed' => 'RSS-flöde',
    '%s updated a comment on the task #%d' => '%s uppdaterade en kommentar på uppgiften #%d',
    '%s commented on the task #%d' => '%s kommenterade uppgiften #%d',
    '%s updated a subtask for the task #%d' => '%s uppdaterade en deluppgift för uppgiften #%d',
    '%s created a subtask for the task #%d' => '%s skapade en deluppgift för uppgiften #%d',
    '%s updated the task #%d' => '%s uppdaterade uppgiften #%d',
    '%s created the task #%d' => '%s skapade uppgiften #%d',
    '%s closed the task #%d' => '%s stängde uppgiften #%d',
    '%s opened the task #%d' => '%s öppnade uppgiften #%d',
    'Activity' => 'Aktivitet',
    'Default values are "%s"' => 'Standardvärden är "%s"',
    'Default columns for new projects (Comma-separated)' => 'Standardkolumner för nya projekt (kommaseparerade)',
    'Task assignee change' => 'Ändra tilldelning av uppgiften',
    '%s changed the assignee of the task #%d to %s' => '%s byt tilldelning av uppgiften #%d till %s',
    '%s changed the assignee of the task %s to %s' => '%s byt tilldelning av uppgiften %s till %s',
    'New password for the user "%s"' => 'Nytt lösenord för användaren "%s"',
    'Choose an event' => 'Välj en händelse',
    'Create a task from an external provider' => 'Skapa en uppgift från en extern leverantör',
    'Change the assignee based on an external username' => 'Ändra tilldelning baserat på ett externt användarnamn',
    'Change the category based on an external label' => 'Ändra kategori baserat på en extern etikett',
    'Reference' => 'Referens',
    'Label' => 'Etikett',
    'Database' => 'Databas',
    'About' => 'Om',
    'Database driver:' => 'Databasdrivrutin:',
    'Board settings' => 'Inställningar för tavla',
    'Webhook settings' => 'Webhook-inställningar',
    'Reset token' => 'Nollställ token',
    'API endpoint:' => 'API-ändpunkt:',
    'Refresh interval for personal board' => 'Uppdateringsintervall för privat tavla',
    'Refresh interval for public board' => 'Uppdateringsintervall för publik tavla',
    'Task highlight period' => 'Period att framhäva ny uppgift',
    'Period (in second) to consider a task was modified recently (0 to disable, 2 days by default)' => 'Period (i sekunder) att betrakta en uppgifts ändring som ny (ange 0 för att inaktivera, 2 dagar är standard)',
    'Frequency in second (60 seconds by default)' => 'Frekvens i sekunder (60 sekunder är standard)',
    'Frequency in second (0 to disable this feature, 10 seconds by default)' => 'Frekvens i sekunder (ange 0 för att inaktivera, 10 sekunder är standard)',
    'Application URL' => 'Applikations-URL',
    'Token regenerated.' => 'Token nyskapad.',
    'Date format' => 'Datumformat',
    'ISO format is always accepted, example: "%s" and "%s"' => 'ISO-format är alltid tillåtet, exempel: "%s" och "%s"',
    'New personal project' => 'Nytt privat projekt',
    'This project is personal' => 'Det här projektet är privat',
    'Add' => 'Lägg till',
    'Start date' => 'Startdatum',
    'Time estimated' => 'Uppskattad tid',
    'There is nothing assigned to you.' => 'Du har inget tilldelat till dig.',
    'My tasks' => 'Mina uppgifter',
    'Activity stream' => 'Aktivitetsström',
    'Dashboard' => 'Översiktspanel',
    'Confirmation' => 'Bekräftelse',
    'Webhooks' => 'Webhooks',
    'API' => 'API',
    'Create a comment from an external provider' => 'Skapa en kommentar från en extern leverantör',
    'Project management' => 'Projekthantering',
    'Columns' => 'Kolumner',
    'Task' => 'Uppgift',
    'Percentage' => 'Procent',
    'Number of tasks' => 'Antal uppgifter',
    'Task distribution' => 'Uppgiftsfördelning',
    'Analytics' => 'Analyser',
    'Subtask' => 'Deluppgift',
    'User repartition' => 'Användardeltagande',
    'Clone this project' => 'Klona projektet',
    'Column removed successfully.' => 'Kolumnen togs bort',
    'Not enough data to show the graph.' => 'Inte tillräckligt med data för att visa graf',
    'Previous' => 'Föregående',
    'The id must be an integer' => 'ID måste vara ett heltal',
    'The project id must be an integer' => 'Projekt-ID måste vara ett heltal',
    'The status must be an integer' => 'Status måste vara ett heltal',
    'The subtask id is required' => 'Deluppgifts-ID behövs',
    'The subtask id must be an integer' => 'Deluppgifts-ID måste vara ett heltal',
    'The task id is required' => 'Uppgifts-ID behövs',
    'The task id must be an integer' => 'Uppgifts-ID måste vara ett heltal',
    'The user id must be an integer' => 'Användar-ID måste vara ett heltal',
    'This value is required' => 'Värdet behövs',
    'This value must be numeric' => 'Värdet måste vara numeriskt',
    'Unable to create this task.' => 'Kunde inte skapa uppgiften.',
    'Cumulative flow diagram' => 'Diagram med kumulativt flöde',
    'Daily project summary' => 'Daglig projektsummering',
    'Daily project summary export' => 'Export av daglig projektsummering',
    'Exports' => 'Exporter',
    'This export contains the number of tasks per column grouped per day.' => 'Denna export innehåller antalet uppgifter per kolumn grupperade per dag.',
    'Active swimlanes' => 'Aktiva simbanor',
    'Add a new swimlane' => 'Lägg till en ny simbana',
    'Default swimlane' => 'Standard-simbana',
    'Do you really want to remove this swimlane: "%s"?' => 'Vill du verkligen ta bort simbanan "%s"?',
    'Inactive swimlanes' => 'Inaktiv simbana',
    'Remove a swimlane' => 'Ta bort en simbana',
    'Swimlane modification for the project "%s"' => 'Ändra simbana för projekt "%s"',
    'Swimlane removed successfully.' => 'Simbanan togs bort',
    'Swimlanes' => 'Simbanor',
    'Swimlane updated successfully.' => 'Simbana uppdaterad',
    'Unable to remove this swimlane.' => 'Kunde inte ta bort simbanan',
    'Unable to update this swimlane.' => 'Kunde inte uppdatera simbanan',
    'Your swimlane has been created successfully.' => 'Din simbana har skapats',
    'Example: "Bug, Feature Request, Improvement"' => 'Exempel: "Bug, ny funktionalitet, förbättringar"',
    'Default categories for new projects (Comma-separated)' => 'Standardkategorier för nya projekt (komma-separerade)',
    'Integrations' => 'Integrationer',
    'Integration with third-party services' => 'Integration med tredjepartstjänster',
    'Subtask Id' => 'Deluppgifts-ID',
    'Subtasks' => 'Deluppgift',
    'Subtasks Export' => 'Exportering av deluppgifter',
    'Task Title' => 'Uppgiftstitel',
    'Untitled' => 'Titel saknas',
    'Application default' => 'Applikationsstandard',
    'Language:' => 'Språk',
    'Timezone:' => 'Tidszon',
    'All columns' => 'Alla kolumner',
    'Next' => 'Nästa',
    '#%d' => '#%d',
    'All swimlanes' => 'Alla simbanor',
    'All colors' => 'Alla färger',
    'Moved to column %s' => 'Flyttad till kolumn %s',
    'User dashboard' => 'Användarens översiktspanel',
    'Allow only one subtask in progress at the same time for a user' => 'Tillåt endast en deluppgift igång samtidigt för en användare',
    'Edit column "%s"' => 'Ändra kolumn "%s"',
    'Select the new status of the subtask: "%s"' => 'Välj ny status för deluppgiften: "%s"',
    'Subtask timesheet' => 'Tidrapport för deluppgiften',
    'There is nothing to show.' => 'Det finns inget att visa.',
    'Time Tracking' => 'Tidsbevakning',
    'You already have one subtask in progress' => 'Du har redan en deluppgift igång',
    'Which parts of the project do you want to duplicate?' => 'Vilka delar av projektet vill du duplicera?',
    'Disallow login form' => 'Förbjud inloggningsformulär',
    'Start' => 'Start',
    'End' => 'Slut',
    'Task age in days' => 'Uppgiftsålder i dagar',
    'Days in this column' => 'Dagar i denna kolumn',
    '%dd' => '%dd',
    'Add a new link' => 'Lägg till ny länk',
    'Do you really want to remove this link: "%s"?' => 'Vill du verkligen ta bort länken: "%s"?',
    'Do you really want to remove this link with task #%d?' => 'Vill du verkligen ta bort länken till uppgiften #%d?',
    'Field required' => 'Fältet krävs',
    'Link added successfully.' => 'Länken har lagts till',
    'Link updated successfully.' => 'Länken har uppdaterats',
    'Link removed successfully.' => 'Länken har tagits bort',
    'Link labels' => 'Länketiketter',
    'Link modification' => 'Länkändring',
    'Opposite label' => 'Motpartslänk',
    'Remove a link' => 'Ta bort en länk',
    'The labels must be different' => 'Etiketterna måste vara olika',
    'There is no link.' => 'Det finns ingen länk',
    'This label must be unique' => 'Etiketten måste vara unik',
    'Unable to create your link.' => 'Kunde inte skapa din länk',
    'Unable to update your link.' => 'Kunde inte uppdatera din länk',
    'Unable to remove this link.' => 'Kunde inte ta bort länken',
    'relates to' => 'relaterar till',
    'blocks' => 'blockerar',
    'is blocked by' => 'blockeras av',
    'duplicates' => 'duplicerar',
    'is duplicated by' => 'är duplicerad av',
    'is a child of' => 'är underliggande till',
    'is a parent of' => 'är överliggande till',
    'targets milestone' => 'milstolpemål',
    'is a milestone of' => 'är en milstolpe för',
    'fixes' => 'åtgärdar',
    'is fixed by' => 'åtgärdas av',
    'This task' => 'Denna uppgift',
    '<1h' => '<1h',
    '%dh' => '%dh',
    'Expand tasks' => 'Fäll ut uppgifter',
    'Collapse tasks' => 'Fäll ihop uppgifter',
    'Expand/collapse tasks' => 'Fäll ut/fäll ihop uppgifter',
    'Close dialog box' => 'Stäng dialogruta',
    'Submit a form' => 'Sänd formulär',
    'Board view' => 'Tavelvy',
    'Keyboard shortcuts' => 'Tangentbordsgenvägar',
    'Open board switcher' => 'Växling av öppen tavla',
    'Application' => 'Applikation',
    'Compact view' => 'Kompakt vy',
    'Horizontal scrolling' => 'Horisontell scroll',
    'Compact/wide view' => 'Kompakt/bred vy',
    'Currency' => 'Valuta',
    'Personal project' => 'Privat projekt',
    'AUD - Australian Dollar' => 'AUD - Australiska dollar',
    'CAD - Canadian Dollar' => 'CAD - Kanadensiska dollar',
    'CHF - Swiss Francs' => 'CHF - Schweiziska franc',
    'Custom Stylesheet' => 'Anpassad stilmall',
    'EUR - Euro' => 'EUR - Euro',
    'GBP - British Pound' => 'GBP - Brittiska pund',
    'INR - Indian Rupee' => 'INR - Indiska rupier',
    'JPY - Japanese Yen' => 'JPY - Japanska yen',
    'NZD - New Zealand Dollar' => 'NZD - Nya Zeeländska dollar',
    'PEN - Peruvian Sol' => 'PEN – Peruansk sol',
    'RSD - Serbian dinar' => 'RSD - Serbiska dinarer',
    'CNY - Chinese Yuan' => 'CNY - Kinesisk yuan',
    'USD - US Dollar' => 'USD - Amerikanska dollar',
    'VES - Venezuelan Bolívar' => 'VES - Venezuelanska bolívar',
    'Destination column' => 'Målkolumn',
    'Move the task to another column when assigned to a user' => 'Flytta uppgiften till en annan kolumn när den tilldelats en användare',
    'Move the task to another column when assignee is cleared' => 'Flytta uppgiften till en annan kolumn när tilldelningen tas bort.',
    'Source column' => 'Källkolumn',
    'Transitions' => 'Övergångar',
    'Executer' => 'Verkställare',
    'Time spent in the column' => 'Tid i kolumnen.',
    'Task transitions' => 'Uppgiftsövergångar',
    'Task transitions export' => 'Export av uppgiftsövergångar',
    'This report contains all column moves for each task with the date, the user and the time spent for each transition.' => 'Denna rapport innehåller alla kolumnförflyttningar för varje uppgift med datum, användare och nedlagd tid vid varje övergång.',
    'Currency rates' => 'Valutakurser',
    'Rate' => 'Kurs',
    'Change reference currency' => 'Ändra referenskurs',
    'Reference currency' => 'Referensvaluta',
    'The currency rate has been added successfully.' => 'Valutakursen har lagts till.',
    'Unable to add this currency rate.' => 'Kunde inte lägga till valutakursen.',
    'Webhook URL' => 'Webhook URL',
    '%s removed the assignee of the task %s' => '%s ta bort tilldelningen av uppgiften %s',
    'Information' => 'Information',
    'Check two factor authentication code' => 'Kolla tvåfaktorsautentiseringsngskod',
    'The two factor authentication code is not valid.' => 'Tvåfaktorsautentiseringskoden är inte giltig.',
    'The two factor authentication code is valid.' => 'Tvåfaktorsautentiseringskoden är giltig.',
    'Code' => 'Kod',
    'Two factor authentication' => 'Tvåfaktorsautentisering',
    'This QR code contains the key URI: ' => 'Denna QR-kod innehåller nyckel-URI:n',
    'Check my code' => 'Verifiera min kod',
    'Secret key: ' => 'Säkerhetsnyckel:',
    'Test your device' => 'Testa din enhet',
    'Assign a color when the task is moved to a specific column' => 'Tilldela en färg när uppgiften flyttas till en viss kolumn',
    '%s via Kanboard' => '%s via Kanboard',
    'Burndown chart' => 'Burndown-diagram',
    'This chart show the task complexity over the time (Work Remaining).' => 'Diagrammet visar uppgiftens svårighet över tid (återstående arbete).',
    'Screenshot taken %s' => 'Skärmdump tagen %s',
    'Add a screenshot' => 'Lägg till en skärmdump',
    'Take a screenshot and press CTRL+V or ⌘+V to paste here.' => 'Ta en skärmdump och tryck CTRL+V för att klistra in här.',
    'Screenshot uploaded successfully.' => 'Skärmdumpen laddades upp.',
    'SEK - Swedish Krona' => 'SEK - Svensk krona',
    'Identifier' => 'Identifierare',
    'Disable two factor authentication' => 'Inaktivera tvåfaktorsautentisering',
    'Do you really want to disable the two factor authentication for this user: "%s"?' => 'Vill du verkligen inaktivera tvåfaktorsautentisering för denna användare: "%s"?',
    'Edit link' => 'Ändra länk',
    'Start to type task title...' => 'Börja skriv uppgiftstitel...',
    'A task cannot be linked to itself' => 'En uppgift kan inte länkas till sig själv',
    'The exact same link already exists' => 'Länken existerar redan',
    'Recurrent task is scheduled to be generated' => 'Återkommande uppgift är schemalagd att genereras',
    'Score' => 'Poäng',
    'The identifier must be unique' => 'Identifieraren måste vara unik',
    'This linked task id doesn\'t exists' => 'Detta länkade uppgifts-ID existerar inte',
    'This value must be alphanumeric' => 'Värdet måste vara alfanumeriskt',
    'Edit recurrence' => 'Ändra återkommande',
    'Generate recurrent task' => 'Generera återkommande uppgift',
    'Trigger to generate recurrent task' => 'Aktivera att generera återkommande uppgift',
    'Factor to calculate new due date' => 'Faktor för att beräkna nytt förfallodatum',
    'Timeframe to calculate new due date' => 'Tidsram för att beräkna nytt förfallodatum',
    'Base date to calculate new due date' => 'Basdatum för att beräkna nytt förfallodatum',
    'Action date' => 'Händelsedatum',
    'Base date to calculate new due date: ' => 'Basdatum för att beräkna nytt förfallodatum: ',
    'This task has created this child task: ' => 'Uppgiften har skapat denna underliggande uppgift: ',
    'Day(s)' => 'Dag(ar)',
    'Existing due date' => 'Existerande förfallodatum',
    'Factor to calculate new due date: ' => 'Faktor för att beräkna nytt förfallodatum: ',
    'Month(s)' => 'Månad(er)',
    'This task has been created by: ' => 'Uppgiften har skapats av: ',
    'Recurrent task has been generated:' => 'Återkommande uppgift har genererats:',
    'Timeframe to calculate new due date: ' => 'Tidsram för att beräkna nytt förfallodatum: ',
    'Trigger to generate recurrent task: ' => 'Aktivera att generera återkommande uppgift: ',
    'When task is closed' => 'När uppgiften är stängd',
    'When task is moved from first column' => 'När uppgiften flyttas från första kolumnen',
    'When task is moved to last column' => 'När uppgiften flyttas till sista kolumnen',
    'Year(s)' => 'År',
    'Project settings' => 'Projektinställningar',
    'Automatically update the start date' => 'Automatisk uppdatering av startdatum',
    'iCal feed' => 'iCal-flöde',
    'Preferences' => 'Preferenser',
    'Security' => 'Säkerhet',
    'Two factor authentication disabled' => 'Tvåfaktorsautentisering inaktiverad',
    'Two factor authentication enabled' => 'Tvåfaktorsautentisering aktiverad',
    'Unable to update this user.' => 'Kunde inte uppdatera användaren.',
    'There is no user management for personal projects.' => 'Det finns ingen användarhantering för privata projekt.',
    'User that will receive the email' => 'Användare som kommer att ta emot e-brevet',
    'Email subject' => 'E-postämne',
    'Date' => 'Datum',
    'Add a comment log when moving the task between columns' => 'Lägg till en kommentarslogg när en uppgift flyttas mellan kolumner',
    'Move the task to another column when the category is changed' => 'Flyttas uppgiften till en annan kolumn när kategorin ändras',
    'Send a task by email to someone' => 'Skicka en uppgift till någon via e-post',
    'Reopen a task' => 'Återöppna en uppgift',
    'Notification' => 'Notis',
    '%s moved the task #%d to the first swimlane' => '%s flyttade uppgiften #%d till första simbanan',
    'Swimlane' => 'Simbana',
    '%s moved the task %s to the first swimlane' => '%s flyttade uppgiften %s till första simbanan',
    '%s moved the task %s to the swimlane "%s"' => '%s flyttade uppgiften %s till simbana "%s"',
    'This report contains all subtasks information for the given date range.' => 'Denna rapport innehåller all deluppgiftsinformation för det givna datumintervallet.',
    'This report contains all tasks information for the given date range.' => 'Denna rapport innehåller all uppgiftsinformation för det givna datumintervallet.',
    'Project activities for %s' => 'Projektaktiviteter för %s',
    'view the board on Kanboard' => 'visa tavlan på Kanboard',
    'The task has been moved to the first swimlane' => 'Uppgiften har flyttats till första simbanan',
    'The task has been moved to another swimlane:' => 'Uppgiften har flyttats till en annan simbana::',
    'New title: %s' => 'Ny titel: %s',
    'The task is not assigned anymore' => 'Uppgiften är inte länge tilldelad',
    'New assignee: %s' => 'Ny tilldelning: %s',
    'There is no category now' => 'Det finns ingen kategori nu',
    'New category: %s' => 'Ny kategori: %s',
    'New color: %s' => 'Ny färg: %s',
    'New complexity: %d' => 'Ny komplexitet: %d',
    'The due date has been removed' => 'Förfallodatumet har tagits bort',
    'There is no description anymore' => 'Det finns ingen beskrivning längre',
    'Recurrence settings has been modified' => 'Återkommande inställning har ändrats',
    'Time spent changed: %sh' => 'Spenderad tid har ändrats: %sh',
    'Time estimated changed: %sh' => 'Tidsuppskattning ändrad: %sh',
    'The field "%s" has been updated' => 'Fältet "%s" har uppdaterats',
    'The description has been modified:' => 'Beskrivningen har modifierats',
    'Do you really want to close the task "%s" as well as all subtasks?' => 'Vill du verkligen stänga uppgiften "%s" och alla deluppgifter?',
    'I want to receive notifications for:' => 'Jag vill få notiser för:',
    'All tasks' => 'Alla uppgifter',
    'Only for tasks assigned to me' => 'Bara för uppgifter tilldelade mig',
    'Only for tasks created by me' => 'Bara för uppgifter skapade av mig',
    'Only for tasks created by me and tasks assigned to me' => 'Bara för uppgifter skapade av mig och tilldelade till mig',
    '%%Y-%%m-%%d' => '%%Y-%%m-%%d',
    'Total for all columns' => 'Totalt för alla kolumner',
    'You need at least 2 days of data to show the chart.' => 'Du behöver minst två dagars data för att visa diagrammet.',
    '<15m' => '<15m',
    '<30m' => '<30m',
    'Stop timer' => 'Stoppa timer',
    'Start timer' => 'Starta timer',
    'My activity stream' => 'Min aktivitetsström',
    'Search tasks' => 'Sök uppgifter',
    'Reset filters' => 'Återställ filter',
    'My tasks due tomorrow' => 'Mina uppgifter förfaller imorgon',
    'Tasks due today' => 'Uppgifter förfaller idag',
    'Tasks due tomorrow' => 'Uppgifter förfaller imorgon',
    'Tasks due yesterday' => 'Uppgifter förföll igår',
    'Closed tasks' => 'Stängda uppgifter',
    'Open tasks' => 'Öppna uppgifter',
    'Not assigned' => 'Inte tilldelad',
    'View advanced search syntax' => 'Visa avancerad söksyntax',
    'Overview' => 'Översikt',
    'Board/Calendar/List view' => 'Tavelvy/kalendervy/listvy',
    'Switch to the board view' => 'Växla till tavelvy',
    'Switch to the list view' => 'Växla till listvy',
    'Go to the search/filter box' => 'Gå till sök/filter box',
    'There is no activity yet.' => 'Det finns ingen aktivitet ännu.',
    'No tasks found.' => 'Inga uppgifter hittades.',
    'Keyboard shortcut: "%s"' => 'Tangentbordsgenväg: "%s"',
    'List' => 'Lista',
    'Filter' => 'Filter',
    'Advanced search' => 'Avancerad sök',
    'Example of query: ' => 'Exempel på fråga',
    'Search by project: ' => 'Sök efter projekt:',
    'Search by column: ' => 'Sök efter kolumn:',
    'Search by assignee: ' => 'Sök efter tilldelad:',
    'Search by color: ' => 'Sök efter färg:',
    'Search by category: ' => 'Sök efter kategori:',
    'Search by description: ' => 'Sök efter beskrivning',
    'Search by due date: ' => 'Sök efter förfallodatum',
    'Average time spent in each column' => 'Medeltidsåtgång i varje kolumn',
    'Average time spent' => 'Medeltidsåtgång',
    'This chart shows the average time spent in each column for the last %d tasks.' => 'Diagramet visar medeltidsåtgång i varje kolumn för de senaste %d uppgifterna.',
    'Average Lead and Cycle time' => 'Medel av led och cykeltid',
    'Average lead time: ' => 'Medel av ledtid',
    'Average cycle time: ' => 'Medel av cykeltid',
    'Cycle Time' => 'Cykeltid',
    'Lead Time' => 'Ledtid',
    'This chart shows the average lead and cycle time for the last %d tasks over the time.' => 'Diagramet visar medel av led och cykeltid för de senaste %d uppgifterna över tiden.',
    'Average time into each column' => 'Medeltidsåtgång i varje kolumn',
    'Lead and cycle time' => 'Led och cykeltid',
    'Lead time: ' => 'Ledtid',
    'Cycle time: ' => 'Cykeltid',
    'Time spent in each column' => 'Tidsåtgång per kolumn',
    'The lead time is the duration between the task creation and the completion.' => 'Ledtiden är varaktigheten mellan uppgiftens skapande och slutförande.',
    'The cycle time is the duration between the start date and the completion.' => 'Cykeltiden är varaktigheten mellan uppgiftens startdatum och slut.',
    'If the task is not closed the current time is used instead of the completion date.' => 'Om uppgiften inte är stängd används nuvarande tid istället för slutförandedatum.',
    'Set the start date automatically' => 'Sätt startdatum automatiskt',
    'Edit Authentication' => 'Ändra autentisering',
    'Remote user' => 'Fjärranvändare',
    'Remote users do not store their password in Kanboard database, examples: LDAP, Google and Github accounts.' => 'Fjärranvändares lösenord lagras inte i Kanboard-databasen, exempel: LDAP, Google och Github-konton.',
    'If you check the box "Disallow login form", credentials entered in the login form will be ignored.' => 'Om du aktiverar boxen "Tillåt inte loginformulär" kommer inloggningsuppgifter i formuläret att ignoreras.',
    'Default task color' => 'Standardfärg för uppgifter',
    'This feature does not work with all browsers.' => 'Denna funktion fungerar inte i alla webbläsare.',
    'There is no destination project available.' => 'Det finns inget destinationsprojekt tillgängligt.',
    'Trigger automatically subtask time tracking' => 'Aktivera automatisk tidsbevakning av deluppgifter',
    'Include closed tasks in the cumulative flow diagram' => 'Inkludera stängda uppgifter i digrammet med kumulativt flöde',
    'Current swimlane: %s' => 'Nuvarande simbana: %s',
    'Current column: %s' => 'Nuvarande kolumn: %s',
    'Current category: %s' => 'Nuvarande kategori: %s',
    'no category' => 'ingen kategori',
    'Current assignee: %s' => 'Nuvarande tilldelning: %s',
    'not assigned' => 'inte tilldelad',
    'Author:' => 'Upphovsman:',
    'contributors' => 'medarbetare',
    'License:' => 'Licens:',
    'License' => 'Licens',
    'Enter the text below' => 'Fyll i texten nedan',
    'Start date:' => 'Startdatum:',
    'Due date:' => 'Slutdatum:',
    'People who are project managers' => 'Personer som är projektledare',
    'People who are project members' => 'Personer som är projektdeltagare',
    'NOK - Norwegian Krone' => 'NOK - Norsk krona',
    'Show this column' => 'Visa kolumn',
    'Hide this column' => 'Dölj kolumn',
    'End date' => 'Slutdatum',
    'Users overview' => 'Användaröversikt',
    'Members' => 'Medlemmar',
    'Shared project' => 'Delat projekt',
    'Project managers' => 'Projektledare',
    'Projects list' => 'Projektlista',
    'End date:' => 'Slutdatum:',
    'Change task color when using a specific task link' => 'Ändra uppgiftsfärg när en viss uppgiftslänk används',
    'Task link creation or modification' => 'Uppgiftslänk skapad eller ändrad',
    'Milestone' => 'Milstolpe',
    'Reset the search/filter box' => 'Återställ sökning/fitrering',
    'Documentation' => 'Dokumentation',
    'Author' => 'Skapad av',
    'Version' => 'Version',
    'Plugins' => 'Insticksprogram',
    'There is no plugin loaded.' => 'Inget insticksprogram har laddats',
    'My notifications' => 'Mina notifieringar',
    'Custom filters' => 'Anpassade filter',
    'Your custom filter has been created successfully.' => 'Ditt anpassade filter har skapats.',
    'Unable to create your custom filter.' => 'Ditt anpassade filter kunde inte skapas.',
    'Custom filter removed successfully.' => 'Ditt anpassade filter har raderats.',
    'Unable to remove this custom filter.' => 'Ditt anpassade filter kunde inte raderas.',
    'Edit custom filter' => 'Redigera anpassat filter',
    'Your custom filter has been updated successfully.' => 'Ditt anpassade filter har uppdaterats',
    'Unable to update custom filter.' => 'Kunde inte uppdatera anpassat filter',
    'Web' => 'Webb',
    'New attachment on task #%d: %s' => 'Ny bilaga i uppgift #%d: %s',
    'New comment on task #%d' => 'Ny kommentar i uppgift #%d',
    'Comment updated on task #%d' => 'Kommentar uppdaterad i uppgift #%d',
    'New subtask on task #%d' => 'Ny deluppgift till uppgift #%d',
    'Subtask updated on task #%d' => 'Deluppgift till uppgift #%d uppdaterad',
    'New task #%d: %s' => 'Ny uppgift #%d: %s',
    'Task updated #%d' => 'Uppgift uppdaterad #%d',
    'Task #%d closed' => 'Uppgift #%d stängd',
    'Task #%d opened' => 'Uppgift #%d öppnad',
    'Column changed for task #%d' => 'Byte av kolumn för uppgift #%d',
    'New position for task #%d' => 'Ny plats för uppgift #%d',
    'Swimlane changed for task #%d' => 'Simbana uppdaterad för uppgift #%d',
    'Assignee changed on task #%d' => 'Uppgiftsinnehavare ändrades på uppgift #%d',
    '%d overdue tasks' => '%d försenade uppgifter',
    'No notification.' => 'Ingen notifiering',
    'Mark all as read' => 'Markera alla som lästa',
    'Mark as read' => 'Markera som läst',
    'Total number of tasks in this column across all swimlanes' => 'Totalt antal uppgifter i denna kolumnen över samtliga simbanor',
    'Collapse swimlane' => 'Fäll ihop simbana',
    'Expand swimlane' => 'Fäll ut simbana',
    'Add a new filter' => 'Lägg till nytt filter',
    'Share with all project members' => 'Dela med alla projektmedlemmar',
    'Shared' => 'Delad',
    'Owner' => 'Ägare',
    'Unread notifications' => 'Olästa notiser',
    'Notification methods:' => 'Notifieringsmetoder:',
    'Unable to read your file' => 'Kunde inte läsa din fil',
    '%d task(s) have been imported successfully.' => '%d uppgift(er) har importerats.',
    'Nothing has been imported!' => 'Inget har importerats!',
    'Import users from CSV file' => 'Importera användare från CSV-fil',
    '%d user(s) have been imported successfully.' => '%d användare har importerats.',
    'Comma' => 'Kommatecken',
    'Semi-colon' => 'Semikolon',
    'Tab' => 'Tabb',
    'Vertical bar' => 'Lodstreck',
    'Double Quote' => 'Dubbla citattecken',
    'Single Quote' => 'Enkla citattecken',
    '%s attached a file to the task #%d' => '%s bifogade en fil till uppgift #%d',
    'There is no column or swimlane activated in your project!' => 'Ingen kolumn eller simbana har aktiverats i ditt projekt!',
    'Append filter (instead of replacement)' => 'Lägg till filter (istället för ersättning)',
    'Append/Replace' => 'Lägg till/ersätt',
    'Append' => 'Lägg till',
    'Replace' => 'Ersätt',
    'Import' => 'Importera',
    'Change sorting' => 'Ändra sortering',
    'Tasks Importation' => 'Importera uppgifter',
    'Delimiter' => 'Avskiljare',
    'Enclosure' => 'Bilaga',
    'CSV File' => 'CSV-fil',
    'Instructions' => 'Instruktioner',
    'Your file must use the predefined CSV format' => 'Din fil måste använda fördefinierat CSV-format',
    'Your file must be encoded in UTF-8' => 'Din fil måste teckenkodas med UTF-8',
    'The first row must be the header' => 'Första raden måste vara rubrik.',
    'Duplicates are not verified for you' => 'Dupliceringar verifieras inte för din användare',
    'The due date must use the ISO format: YYYY-MM-DD' => 'Förfallodatum måste använda ISO-datumformat: ÅÅÅÅ-MM-DD',
    'Download CSV template' => 'Ladda ner CSV-mall',
    'No external integration registered.' => 'Ingen extern integration registrerad.',
    'Duplicates are not imported' => 'Dubletter importeras inte',
    'Usernames must be lowercase and unique' => 'Användarnamn måste vara unika och endast bestå av gemener ',
    'Passwords will be encrypted if present' => 'Eventuella lösenord kommer krypteras',
    '%s attached a new file to the task %s' => '%s bifogade en ny fil till uppgiften %s',
    'Link type' => 'Länktyp',
    'Assign automatically a category based on a link' => 'Tilldela kategori automatiskt baserat på en länk',
    'BAM - Konvertible Mark' => 'BAM - Konvertibla mark',
    'Assignee Username' => 'Uppdragsinnehavares användarnamn',
    'Assignee Name' => 'Uppdragsinnehavares namn',
    'Groups' => 'Grupper',
    'Members of %s' => 'Medlemmar i %s',
    'New group' => 'Ny grupp',
    'Group created successfully.' => 'Grupp skapades',
    'Unable to create your group.' => 'Kunde inte skapa gruppen',
    'Edit group' => 'Redigera grupp',
    'Group updated successfully.' => 'Gruppen uppdaterades.',
    'Unable to update your group.' => 'Kunde inte uppdatera gruppen',
    'Add group member to "%s"' => 'Lägg till gruppmedlem till "%s"',
    'Group member added successfully.' => 'Gruppmedlem lades till.',
    'Unable to add group member.' => 'Kunde inte lägga till gruppmedlem.',
    'Remove user from group "%s"' => 'Ta bort användare från grupp "%s"',
    'User removed successfully from this group.' => 'Användaren har tagits bort från gruppen.',
    'Unable to remove this user from the group.' => 'Kunde inte ta bort användaren från gruppen.',
    'Remove group' => 'Ta bort grupp',
    'Group removed successfully.' => 'Gruppen har raderats',
    'Unable to remove this group.' => 'Kunde inte radera gruppen.',
    'Project Permissions' => 'Projektbehörighet',
    'Manager' => 'Ledare',
    'Project Manager' => 'Projektägare',
    'Project Member' => 'Projektmedlem',
    'Project Viewer' => 'Projektläsare',
    'Your account is locked for %d minutes' => 'Ditt konto har låsts i %d minuter',
    'Invalid captcha' => 'Ogiltig captcha',
    'The name must be unique' => 'Namnet måste vara unikt',
    'View all groups' => 'Visa alla grupper',
    'There is no user available.' => 'Ingen användare tillgänglig',
    'Do you really want to remove the user "%s" from the group "%s"?' => 'Vill du verkligen ta bort användaren "%s" från gruppen "%s"?',
    'There is no group.' => 'Inga grupper existerar.',
    'Add group member' => 'Lägg till gruppmedlem',
    'Do you really want to remove this group: "%s"?' => 'Vill du verkligen ta bort gruppen: "%s"?',
    'There is no user in this group.' => 'Det finns inga användare i gruppen.',
    'Permissions' => 'Behörigheter',
    'Allowed Users' => 'Behöriga användare',
    'No specific user has been allowed.' => 'Ingen särskild användare har beviljats.',
    'Role' => 'Roll',
    'Enter user name...' => 'Mata in användarnamn...',
    'Allowed Groups' => 'Tillåtna grupper',
    'No group has been allowed.' => 'Ingen grupp har beviljats.',
    'Group' => 'Grupp',
    'Group Name' => 'Gruppnamn',
    'Enter group name...' => 'Mata in gruppnamn...',
    'Role:' => 'Roll:',
    'Project members' => 'Projektmedlemmar',
    '%s mentioned you in the task #%d' => '%s nämnde dig i uppgift #%d',
    '%s mentioned you in a comment on the task #%d' => '%s nämnde dig i en kommentar till uppgift #%d',
    'You were mentioned in the task #%d' => 'Du nämndes i uppgift #%d',
    'You were mentioned in a comment on the task #%d' => 'Du nämndes i en kommentar till uppgift #%d',
    'Estimated hours: ' => 'Uppskattat antal timmar',
    'Actual hours: ' => 'Verkligt antal timmar',
    'Hours Spent' => 'Upparbetade timmar',
    'Hours Estimated' => 'Uppskattat antal timmar',
    'Estimated Time' => 'Estimerad tid',
    'Actual Time' => 'Faktisk tid',
    'Estimated vs actual time' => 'Estimerad vs faktisk tid',
    'RUB - Russian Ruble' => 'RUB - Rysk rubel',
    'Assign the task to the person who does the action when the column is changed' => 'Tilldela uppgiften till personen som utför åtgärden när kolumnen ändras',
    'Close a task in a specific column' => 'Stäng en uppgift i en viss kolumn',
    'Time-based One-time Password Algorithm' => 'Tidsbaserade engångslösenord',
    'Two-Factor Provider: ' => 'Tvåfaktorsleverantör:',
    'Disable two-factor authentication' => 'Inaktivera tvåfaktorsautentisering',
    'Enable two-factor authentication' => 'Aktivera tvåfaktorsautentisering',
    'There is no integration registered at the moment.' => 'Ingen integration har registrerats.',
    'Password Reset for Kanboard' => 'Lösenordsåterställning för Kanboard',
    'Forgot password?' => 'Glömt lösenordet?',
    'Enable "Forget Password"' => 'Aktivera "Glömt lösenord"',
    'Password Reset' => 'Återställ lösenord',
    'New password' => 'Nytt lösenord',
    'Change Password' => 'Ändra lösenord',
    'To reset your password click on this link:' => 'För att ändra lösenord klicka på denna länk:',
    'Last Password Reset' => 'Senaste lösenordsåterställning',
    'The password has never been reinitialized.' => 'Lösenordet har aldrig nollställts.',
    'Creation' => 'Skapat',
    'Expiration' => 'Utgång',
    'Password reset history' => 'Historik för lösenordsåterställning',
    'All tasks of the column "%s" and the swimlane "%s" have been closed successfully.' => 'Alla uppgifter i kolumnen "%s" samt simbanan "%s" har stängts.',
    'Do you really want to close all tasks of this column?' => 'Vill du verkligen stänga alla uppgifter i denna kolumn?',
    '%d task(s) in the column "%s" and the swimlane "%s" will be closed.' => '%d uppgift(er) i kolumnen "%s" och simbanan "%s" kommer stängas.',
    'Close all tasks in this column and this swimlane' => 'Stäng alla uppgifter i denna kolumn',
    'No plugin has registered a project notification method. You can still configure individual notifications in your user profile.' => 'Inget insticksprogram har registrerat notifieringsmetod för projektet. Du kan fortfarande konfigurera personliga notifikationer i din användarprofil.',
    'My dashboard' => 'Min översiktspanel',
    'My profile' => 'Min profil',
    'Project owner: ' => 'Projektägare: ',
    'The project identifier is optional and must be alphanumeric, example: MYPROJECT.' => 'Identifierare för projektet är inte obligatorisk men måste vara alfanumerisk, t.ex.: AVDELNINGX',
    'Project owner' => 'Projektägare',
    'Personal projects do not have users and groups management.' => 'Privata projekt saknar hantering för användare och grupper.',
    'There is no project member.' => 'Det finns ingen projekmedlem.',
    'Priority' => 'Prioritet',
    'Task priority' => 'Uppgiftsprioritet',
    'General' => 'Allmänt',
    'Dates' => 'Datu',
    'Default priority' => 'Standardprioritet',
    'Lowest priority' => 'Låg prioritet',
    'Highest priority' => 'Hög prioritet',
    'Close a task when there is no activity' => 'Stäng uppgift utan aktivitet',
    'Duration in days' => 'Varaktighet i dagar',
    'Send email when there is no activity on a task' => 'Skicka e-post när aktivitet i en uppgift upphör',
    'Unable to fetch link information.' => 'Kunde inte hämta länkinformation.',
    'Daily background job for tasks' => 'Dagligt bakgrundsjobb för uppgifter',
    'Auto' => 'Auto',
    'Related' => 'Relaterat',
    'Attachment' => 'Bilaga',
    'Title not found' => 'Titel hittades inte',
    'Web Link' => 'Webblänk',
    'External links' => 'Externa länkar',
    'Add external link' => 'Skapa extern länk',
    'Type' => 'Typ',
    'Dependency' => 'Beroende',
    'Add internal link' => 'Lägg till intern länk',
    'Add a new external link' => 'Lägg till extern länk',
    'Edit external link' => 'Redigera extern länk',
    'External link' => 'Extern länk',
    'Copy and paste your link here...' => 'Klistra in länken här...',
    'URL' => 'URL',
    'Internal links' => 'Intern länk',
    'Assign to me' => 'Tilldela mig',
    'Me' => 'Jag',
    'Do not duplicate anything' => 'Kopiera inte',
    'Projects management' => 'Projekthantering',
    'Users management' => 'Användarhantering',
    'Groups management' => 'Grupphantering',
    'Create from another project' => 'Skapa från annat projekt',
    'open' => 'öppen',
    'closed' => 'stängd',
    'Priority:' => 'Prioritet:',
    'Reference:' => 'Referens:',
    'Complexity:' => 'Komplexitet:',
    'Swimlane:' => 'Simbana:',
    'Column:' => 'Kolumn',
    'Position:' => 'Position:',
    'Creator:' => 'Skapad av:',
    'Time estimated:' => 'Uppskattad tid:',
    '%s hours' => '%s timmar',
    'Time spent:' => 'Spenderad tid:',
    'Created:' => 'Skapad:',
    'Modified:' => 'Ändrad',
    'Completed:' => 'Färdig:',
    'Started:' => 'Påbörjad:',
    'Moved:' => 'Flyttad:',
    'Task #%d' => 'Uppgift #%d',
    'Time format' => 'Tidsformat',
    'Start date: ' => 'Startdatum:',
    'End date: ' => 'Slutdatum: ',
    'New due date: ' => 'Nytt förfallodatum: ',
    'Start date changed: ' => 'Startdatum ändrat:',
    'Disable personal projects' => 'Inaktivera personliga projekt',
    'Do you really want to remove this custom filter: "%s"?' => 'Vill du verkligen ta bort anpassat filter: "%s"?',
    'Remove a custom filter' => 'Ta bort ett anpassat filter',
    'User activated successfully.' => 'Användare aktiverad.',
    'Unable to enable this user.' => 'Kunde inte aktivera användaren.',
    'User disabled successfully.' => 'Användaren inaktiverad.',
    'Unable to disable this user.' => 'Kunde inte inaktivera användaren.',
    'All files have been uploaded successfully.' => 'Samtliga filer har laddats upp.',
    'The maximum allowed file size is %sB.' => 'Maximal filstorlek är %sB.',
    'Drag and drop your files here' => 'Dra och släpp dina filer här',
    'choose files' => 'välj filer',
    'View profile' => 'Visa profil',
    'Two Factor' => 'Tvåfaktor',
    'Disable user' => 'Inaktivera användare',
    'Do you really want to disable this user: "%s"?' => 'Vill du verkligen inaktivera följande användare: "%s"?',
    'Enable user' => 'Aktivera användare',
    'Do you really want to enable this user: "%s"?' => 'Vill du verkligen aktivera följande användare: "%s"?',
    'Download' => 'Ladda ner',
    'Uploaded: %s' => 'Laddat upp: %s',
    'Size: %s' => 'Storlek: %s',
    'Uploaded by %s' => 'Uppladdat av %s',
    'Filename' => 'Filnamn',
    'Size' => 'Storlek',
    'Column created successfully.' => 'Kolumnen skapades.',
    'Another column with the same name exists in the project' => 'En annan kolumn med samma namn finns redan i projektet',
    'Default filters' => 'Standardfilter',
    'Your board doesn\'t have any columns!' => 'Tavlan har inga kolumner!',
    'Change column position' => 'Ändra kolumnposition',
    'Switch to the project overview' => 'Gå till projektöversikt',
    'User filters' => 'Användarfilter',
    'Category filters' => 'Kategorifilter',
    'Upload a file' => 'Ladda upp en fil',
    'View file' => 'Visa fil',
    'Last activity' => 'Senaste aktivitet',
    'Change subtask position' => 'Ändra position på deluppgift',
    'This value must be greater than %d' => 'Detta värde måste vara större än %d',
    'Another swimlane with the same name exists in the project' => 'En simbana med samma namn finns redan i projektet',
    'Example: https://example.kanboard.org/ (used to generate absolute URLs)' => 'Exempel: https://example.kanboard.org/ (används för att generera absoluta URL:er)',
    'Actions duplicated successfully.' => 'Åtgärder duplicerades.',
    'Unable to duplicate actions.' => 'Kunde inte duplicera åtgärder.',
    'Add a new action' => 'Skapa en ny åtgärd',
    'Import from another project' => 'Importera från ett annat projekt',
    'There is no action at the moment.' => 'Det finns ingen åtgärd.',
    'Import actions from another project' => 'Importera åtgärder från ett annat projekt',
    'There is no available project.' => 'Inget tillgängligt projekt.',
    'Local File' => 'Lokal fil',
    'Configuration' => 'Konfiguration',
    'PHP version:' => 'PHP-version:',
    'PHP SAPI:' => 'PHP SAPI:',
    'OS version:' => 'OS-version:',
    'Database version:' => 'Databas-version:',
    'Browser:' => 'Webbläsare:',
    'Task view' => 'Uppgiftsvy',
    'Edit task' => 'Ändra uppgift',
    'Edit description' => 'Ändra beskrivning',
    'New internal link' => 'Ny intern länk',
    'Display list of keyboard shortcuts' => 'Visa lista av kortkommandon',
    'Avatar' => 'Avatar',
    'Upload my avatar image' => 'Ladda upp min avatar',
    'Remove my image' => 'Radera min bild',
    'The OAuth2 state parameter is invalid' => 'Tillståndsparametern till OAuth2 är ogiltig',
    'User not found.' => 'Användaren hittades inte.',
    'Search in activity stream' => 'Sök i aktivitetsström',
    'My activities' => 'Mina aktiviteter',
    'Activity until yesterday' => 'Aktivitet fram till igår',
    'Activity until today' => 'Aktivitet fram till idag',
    'Search by creator: ' => 'Sök på skapare: ',
    'Search by creation date: ' => 'Sök på skapandedatum: ',
    'Search by task status: ' => 'Sök på uppgiftsstatus: ',
    'Search by task title: ' => 'Sök på uppgiftstitel: ',
    'Activity stream search' => 'Sök i aktivitetsström',
    'Projects where "%s" is manager' => 'Projekt där "%s" är ledare',
    'Projects where "%s" is member' => 'Projekt där "%s" är medlem',
    'Open tasks assigned to "%s"' => 'Öppna uppgifter tilldelade till "%s"',
    'Closed tasks assigned to "%s"' => 'Stängda uppgifter tilldelade till "%s"',
    'Assign automatically a color based on a priority' => 'Tilldela färg baserat på prioritet automatiskt',
    'Overdue tasks for the project(s) "%s"' => 'Försenade uppgifter för projekt(en) "%s"',
    'Upload files' => 'Ladda upp filer',
    'Installed Plugins' => 'Installerade insticksprogram',
    'Plugin Directory' => 'Katalog för insticksprogram',
    'Plugin installed successfully.' => 'Insticksprogram installerat.',
    'Plugin updated successfully.' => 'Insticksprogram uppdaterat.',
    'Plugin removed successfully.' => 'Insticksprogram borttaget.',
    'Subtask converted to task successfully.' => 'Deluppgift konverterades till uppgift.',
    'Unable to convert the subtask.' => 'Kunde inte konvertera deluppgift.',
    'Unable to extract plugin archive.' => 'Kunde inte packa upp arkivet med insticksprogram.',
    'Plugin not found.' => 'Insticksprogram kunde inte hittas.',
    'You don\'t have the permission to remove this plugin.' => 'Du har inte behörighet att radera insticksprogrammet.',
    'Unable to download plugin archive.' => 'Kunde inte ladda ner arkiv med insticksprogram.',
    'Unable to write temporary file for plugin.' => 'Kunde inte skriva temporär fil för insticksprogram.',
    'Unable to open plugin archive.' => 'Kunde inte öppna arkiv med insticksprogram.',
    'There is no file in the plugin archive.' => 'Filer saknas i insticksprogramarkivet.',
    'Create tasks in bulk' => 'Skapa uppgifter i bulk',
    'Your Kanboard instance is not configured to install plugins from the user interface.' => 'Din instans av Kanboard är inte konfigurerad för att installera insticksprogram från användergränssnittet.',
    'There is no plugin available.' => 'Inget insticksprogram tillgängligt.',
    'Install' => 'Installera',
    'Update' => 'Uppdatera',
    'Up to date' => 'Uppdaterad',
    'Not available' => 'Inte tillgänglig',
    'Remove plugin' => 'Radera insticksprogram',
    'Do you really want to remove this plugin: "%s"?' => 'Vill du verkligen radera insticksprogram: "%s"?',
    'Uninstall' => 'Avinstallera',
    'Listing' => 'Listar',
    'Metadata' => 'Metadata',
    'Manage projects' => 'Hantera projekt',
    'Convert to task' => 'Konvertera till uppgift',
    'Convert sub-task to task' => 'Konvertera deluppgift till uppgift',
    'Do you really want to convert this sub-task to a task?' => 'Vill du verkligen konvertera deluppgiften till en uppgift?',
    'My task title' => 'Titel på min uppgift',
    'Enter one task by line.' => 'Fyll i en uppgift per rad.',
    'Number of failed login:' => 'Antal misslyckade inloggningar:',
    'Account locked until:' => 'Kontot låst till:',
    'Email settings' => 'E-postinställningar',
    'Email sender address' => 'E-postavsändare',
    'Email transport' => 'Transportval för e-post',
    'Webhook token' => 'Token för webhooks',
    'Project tags management' => 'Projektmärkningshantering',
    'Tag created successfully.' => 'Märkning skapades.',
    'Unable to create this tag.' => 'Kunde inte skapa märkning.',
    'Tag updated successfully.' => 'Märkning uppdaterad.',
    'Unable to update this tag.' => 'Kunde inte uppdatera märkning.',
    'Tag removed successfully.' => 'Märkning har tagits bort.',
    'Unable to remove this tag.' => 'Kunde inte ta bort märkningen.',
    'Global tags management' => 'Global märkningshantering',
    'Tags' => 'Märkningar',
    'Tags management' => 'Märkningshantering',
    'Add new tag' => 'Lägg till ny märkning',
    'Edit a tag' => 'Ändra en märkning',
    'Project tags' => 'Projektmärkningar',
    'There is no specific tag for this project at the moment.' => 'Det finns ingen märkning i projektet ännu.',
    'Tag' => 'Märkning',
    'Remove a tag' => 'Ta bort en märkning',
    'Do you really want to remove this tag: "%s"?' => 'Vill du verkligen ta bort märkningen "%s"?',
    'Global tags' => 'Globala märkningar',
    'There is no global tag at the moment.' => 'Det finns ingen global märkning ännu.',
    'This field cannot be empty' => 'Detta fältet kan inte lämnas tomt',
    'Close a task when there is no activity in a specific column' => 'Stäng en uppgift om aktivitet saknas i en viss kolumn',
    '%s removed a subtask for the task #%d' => '%s tog bort en deluppgift i aktivitet #%d',
    '%s removed a comment on the task #%d' => '%s tog bort en kommentar på aktivitet #%d',
    'Comment removed on task #%d' => 'Kommentar borttagen från aktivitet #%d',
    'Subtask removed on task #%d' => 'Deluppgift borttagen från aktivitet #%d',
    'Hide tasks in this column in the dashboard' => 'Göm uppgifter i denna kolumn på översiktspanelen',
    '%s removed a comment on the task %s' => '%s tog bort en kommentar från uppgiften %s',
    '%s removed a subtask for the task %s' => '%s tog bort en deluppgift från uppgiften %s',
    'Comment removed' => 'Kommentar borttagen',
    'Subtask removed' => 'Deluppgift borttagen',
    '%s set a new internal link for the task #%d' => '%s tilldelade en ny intern länk till uppgift #%d',
    '%s removed an internal link for the task #%d' => '%s tog bort en intern länk från uppgift #%d',
    'A new internal link for the task #%d has been defined' => 'En ny intern länk har skapats till uppgift #%d',
    'Internal link removed for the task #%d' => 'Intern länk togs bort från uppgift #%d',
    '%s set a new internal link for the task %s' => '%s tilldelade en ny intern länk till uppgiften %s',
    '%s removed an internal link for the task %s' => '%s tog bort en intern länk från uppgiften %s',
    'Automatically set the due date on task creation' => 'Sätt förfallodatum automatiskt vid skapande av uppgift',
    'Move the task to another column when closed' => 'Flytta uppgiften till en annan kolumn när den stängs',
    'Move the task to another column when not moved during a given period' => 'Flytta uppgiften till en annan kolumn när den inte flyttats under en given tidsperiod',
    'Dashboard for %s' => 'Översiktspanel för %s',
    'Tasks overview for %s' => 'Uppgiftsöversikt för %s',
    'Subtasks overview for %s' => 'Deluppgiftsöversikt för %s',
    'Projects overview for %s' => 'Projektöversikt för %s',
    'Activity stream for %s' => 'Aktivitetsström för %s',
    'Assign a color when the task is moved to a specific swimlane' => 'Tilldela en färg till uppgiften när den flyttas till en viss simbana',
    'Assign a priority when the task is moved to a specific swimlane' => 'Tilldela en prioritet till uppgiften när den flyttas till en viss simbana',
    'User unlocked successfully.' => 'Användare upplåst.',
    'Unable to unlock the user.' => 'Kunde inte låsa upp användare.',
    'Move a task to another swimlane' => 'Flytta en uppgift till en annan simbana',
    'Creator Name' => 'Namn på skapare',
    'Time spent and estimated' => 'Förbrukad och uppskattad tid',
    'Move position' => 'Flytta position',
    'Move task to another position on the board' => 'Flytta uppgiften till en annan position på tavlan',
    'Insert before this task' => 'Infoga före denna uppgift',
    'Insert after this task' => 'Infoga efter denna uppgift',
    'Unlock this user' => 'Lås upp denna användare',
    'Custom Project Roles' => 'Anpassade projektroller',
    'Add a new custom role' => 'Skapa ny anpassad roll',
    'Restrictions for the role "%s"' => 'Restriktioner för roll "%s"',
    'Add a new project restriction' => 'Lägg till ny projektrestriktion',
    'Add a new drag and drop restriction' => 'Lägg till ny dra-och-släpprestriktion',
    'Add a new column restriction' => 'Lägg till ny kolumnrestriktion',
    'Edit this role' => 'Ändra denna rollen',
    'Remove this role' => 'Ta bort denna rollen',
    'There is no restriction for this role.' => 'Det finns inga restriktioner för denna rollen',
    'Only moving task between those columns is permitted' => 'Endast tillåtet att flytta uppgifter mellan dessa kolumner',
    'Close a task in a specific column when not moved during a given period' => 'Stäng en uppgift i en specifik kolumn om den inte flyttas under en viss period',
    'Edit columns' => 'Redigera kolumner',
    'The column restriction has been created successfully.' => 'Kolumnbegränsningen har skapats.',
    'Unable to create this column restriction.' => 'Det gick inte att skapa denna kolumnbegränsning.',
    'Column restriction removed successfully.' => 'Kolumnbegränsningen har tagits bort.',
    'Unable to remove this restriction.' => 'Det gick inte att ta bort denna begränsning.',
    'Your custom project role has been created successfully.' => 'Din anpassade projektroll har skapats.',
    'Unable to create custom project role.' => 'Det gick inte att skapa anpassad projektroll.',
    'Your custom project role has been updated successfully.' => 'Din anpassade projektroll har uppdaterats.',
    'Unable to update custom project role.' => 'Det gick inte att uppdatera anpassad projektroll.',
    'Custom project role removed successfully.' => 'Anpassad projektroll har tagits bort.',
    'Unable to remove this project role.' => 'Det gick inte att ta bort denna projektroll.',
    'The project restriction has been created successfully.' => 'Projektbegränsningen har skapats.',
    'Unable to create this project restriction.' => 'Det gick inte att skapa denna projektbegränsning.',
    'Project restriction removed successfully.' => 'Projektbegränsningen har tagits bort.',
    'You cannot create tasks in this column.' => 'Du kan inte skapa uppgifter i denna kolumn.',
    'Task creation is permitted for this column' => 'Uppgiftsskapande är tillåtet för denna kolumn',
    'Closing or opening a task is permitted for this column' => 'Att stänga eller öppna en uppgift är tillåtet för denna kolumn',
    'Task creation is blocked for this column' => 'Uppgiftsskapande är blockerat för denna kolumn',
    'Closing or opening a task is blocked for this column' => 'Att stänga eller öppna en uppgift är blockerat för denna kolumn',
    'Task creation is not permitted' => 'Uppgiftsskapande är inte tillåtet',
    'Closing or opening a task is not permitted' => 'Att stänga eller öppna en uppgift är inte tillåtet',
    'New drag and drop restriction for the role "%s"' => 'Ny dra-och-släpp-begränsning för rollen "%s"',
    'People belonging to this role will be able to move tasks only between the source and the destination column.' => 'Personer med denna roll kan endast flytta uppgifter mellan käll- och destinationskolumnen.',
    'Remove a column restriction' => 'Ta bort en kolumnbegränsning',
    'Do you really want to remove this column restriction: "%s" to "%s"?' => 'Vill du verkligen ta bort denna kolumnbegränsning: "%s" till "%s"?',
    'New column restriction for the role "%s"' => 'Ny kolumnbegränsning för rollen "%s"',
    'Rule' => 'Regel',
    'Do you really want to remove this column restriction?' => 'Vill du verkligen ta bort denna kolumnbegränsning?',
    'Custom roles' => 'Anpassade roller',
    'New custom project role' => 'Ny anpassad projektroll',
    'Edit custom project role' => 'Redigera anpassad projektroll',
    'Remove a custom role' => 'Ta bort en anpassad roll',
    'Do you really want to remove this custom role: "%s"? All people assigned to this role will become project member.' => 'Vill du verkligen ta bort denna anpassade roll: "%s"? Alla personer tilldelade denna roll kommer att bli projektmedlemmar.',
    'There is no custom role for this project.' => 'Det finns ingen anpassad roll för detta projekt.',
    'New project restriction for the role "%s"' => 'Ny projektrestriktion för roll "%s"',
    'Restriction' => 'Restriktion',
    'Remove a project restriction' => 'Ta bort en projektrestriktion',
    'Do you really want to remove this project restriction: "%s"?' => 'Vill du verkligen ta bort projektrestriktion: "%s"?',
    'Duplicate to multiple projects' => 'Duplicera till multipla projekt',
    'This field is required' => 'Detta fält måste vara ifyllt',
    'Moving a task is not permitted' => 'Flytt av uppgift ej tillåten',
    'This value must be in the range %d to %d' => 'Värdet måste vara mellan %d och %d',
    'You are not allowed to move this task.' => 'Du har inte behörighet att flytta uppgiften.',
    'API User Access' => 'Användarbehörighet för API',
    'Preview' => 'Förhandsvisning',
    'Write' => 'Skriv',
    'Write your text in Markdown' => 'Uppgiftsbeskrivning i Markdown-format',
    'No personal API access token registered.' => 'Ingen personlig API-token registrerad.',
    'Your personal API access token is "%s"' => 'Din personliga API-token är "%s"',
    'Remove your token' => 'Radera din token',
    'Generate a new token' => 'Generera ny token',
    'Showing %d-%d of %d' => 'Visar %d-%d av %d',
    'Outgoing Emails' => 'Utgående e-post',
    'Add or change currency rate' => 'Lägg till eller ändra valutakurs',
    'Reference currency: %s' => 'Referensvaluta: %s',
    'Add custom filters' => 'Lägg till anpassade filter',
    'Export' => 'Exportera',
    'Add link label' => 'Lägg till länketikett',
    'Incompatible Plugins' => 'Okompatibla insticksprogram',
    'Compatibility' => 'Kompatibilitet',
    'Permissions and ownership' => 'Behörighet och ägarskap',
    'Priorities' => 'Prioriteringar',
    'Close this window' => 'Stäng detta fönster',
    'Unable to upload this file.' => 'Kunde inte ladda upp filen.',
    'Import tasks' => 'Importera uppgifter',
    'Choose a project' => 'Välj ett projekt',
    'Profile' => 'Profil',
    'Application role' => 'Applikationsroll',
    '%d invitations were sent.' => '%d inbjudningar skickades.',
    '%d invitation was sent.' => '%d inbjudan skickades.',
    'Unable to create this user.' => 'Kunde inte skapa användaren.',
    'Kanboard Invitation' => 'Kanboard-inbjudan',
    'Visible on dashboard' => 'Synlig på översiktspanel',
    'Created at:' => 'Skapad vid:',
    'Updated at:' => 'Uppdaterad vid;',
    'There is no custom filter.' => 'Det finns inget anpassat filter.',
    'New User' => 'Ny användare',
    'Authentication' => 'Autentisering',
    'If checked, this user will use a third-party system for authentication.' => 'Vid ikryssning får denna användare använda ett tredjepartssystem för autentisering.',
    'The password is necessary only for local users.' => 'Lösenordet är endast nödvändigt för lokala användare.',
    'You have been invited to register on Kanboard.' => 'Du har blivit inbjuden att registrera dig på Kanboard',
    'Click here to join your team' => 'Klicka här för att gå med i gruppen',
    'Invite people' => 'Bjud in',
    'Emails' => 'E-brev',
    'Enter one email address by line.' => 'Skriv en e-postadress per rad.',
    'Add these people to this project' => 'Lägg till dessa personer till projektet',
    'Add this person to this project' => 'Lägg till denna person till projektet',
    'Sign-up' => 'Registrera',
    'Credentials' => 'Inloggningsuppgifter',
    'New user' => 'Ny användare',
    'This username is already taken' => 'Detta användarnamnet är redan upptaget',
    'Your profile must have a valid email address.' => 'Din profil måste ha en giltig e-postadress.',
    'TRL - Turkish Lira' => 'TRL - Turkisk lira',
    'The project email is optional and could be used by several plugins.' => 'Att ange en e-post för projektet är frivilligt och kan användas av flera insticksmoduler.',
    'The project email must be unique across all projects' => 'Projektets e-post måste vara unik för projektet',
    'The email configuration has been disabled by the administrator.' => 'E-postkonfigurationen har inaktiverats av administratören.',
    'Close this project' => 'Stäng projektet',
    'Open this project' => 'Öppna projektet',
    'Close a project' => 'Stäng ett projekt',
    'Do you really want to close this project: "%s"?' => 'Vill du verkligen stänga projektet "%s"?',
    'Reopen a project' => 'Återöppna ett projekt',
    'Do you really want to reopen this project: "%s"?' => 'Vill du verkligen återöppna projektet "%s"?',
    'This project is open' => 'Projektet är öppet',
    'This project is closed' => 'Projektet är stängt',
    'Unable to upload files, check the permissions of your data folder.' => 'Kunde inte ladda upp filer. Kontrollera rättigheterna på din datakatalog.',
    'Another category with the same name exists in this project' => 'En annan kategori med samma namn finns redan i projektet',
    'Comment sent by email successfully.' => 'Kommentar skickad via e-post.',
    'Sent by email to "%s" (%s)' => 'Skickad via e-post till "%s" (%s)',
    'Unable to read uploaded file.' => 'Kan inte läsa uppladdad fil.',
    'Database uploaded successfully.' => 'Databas uppladdad.',
    'Task sent by email successfully.' => 'Uppgifter skickade via mail.',
    'There is no category in this project.' => 'Det finns ingen kategori i detta projektet.',
    'Send by email' => 'Skicka via e-post',
    'Create and send a comment by email' => 'Skapa och skicka en kommentar via e-post',
    'Subject' => 'Ärende',
    'Upload the database' => 'Ladda upp databasen',
    'You could upload the previously downloaded Sqlite database (Gzip format).' => 'Du kan ladda upp den tidigare nedladdade Sqlite-databasen (i Gzip-format).',
    'Database file' => 'Databasfil',
    'Upload' => 'Ladda upp',
    'Your project must have at least one active swimlane.' => 'Ditt projekt måste ha åtminstone en aktiv simbana.',
    'Project: %s' => 'Projekt: %s',
    'Automatic action not found: "%s"' => 'Automatisk åtgärd kunde inte hittas: "%s"',
    '%d projects' => '%d projekt',
    '%d project' => '%d projekt',
    'There is no project.' => 'Det finns inget projekt',
    'Sort' => 'Sortera',
    'Project ID' => 'Projekt-id',
    'Project name' => 'Projektnamn',
    'Public' => 'Offentlig',
    'Personal' => 'Personlig',
    '%d tasks' => '%d uppgifter',
    '%d task' => '%d uppgift',
    'Task ID' => 'Uppgift-id',
    'Assign automatically a color when due date is expired' => 'Tilldela en färg automatiskt när förfallodatum har passerat',
    'Total score in this column across all swimlanes' => 'Total poäng i denna kolumn över samtliga simbanor',
    'HRK - Kuna' => 'HRK - kuna',
    'ARS - Argentine Peso' => 'ARS - Argentisk peso',
    'COP - Colombian Peso' => 'COP - Colombiansk peso',
    '%d groups' => '%d grupper',
    '%d group' => '%d grupp',
    'Group ID' => 'Grupp-id',
    'External ID' => 'Externt id',
    '%d users' => '%d användare',
    '%d user' => '%d användare',
    'Hide subtasks' => 'Göm deluppgifter',
    'Show subtasks' => 'Visa deluppgifter',
    'Authentication Parameters' => 'Autentiseringsparametrar',
    'API Access' => 'API-tillgång',
    'No users found.' => 'Inga användare hittades.',
    'User ID' => 'Användar-id',
    'Notifications are activated' => 'Notifieringar är aktiverade',
    'Notifications are disabled' => 'Notifieringar är inaktiverade',
    'User disabled' => 'Användare inaktiverad',
    '%d notifications' => '%d notifieringar',
    '%d notification' => '%d notifiering',
    'There is no external integration installed.' => 'Ingen extern integration har installerats.',
    'You are not allowed to update tasks assigned to someone else.' => 'Du har inte tillåtelse att uppdatera uppgifter som är tilldelade till någon annan.',
    'You are not allowed to change the assignee.' => 'Du har inte behörighet att ändra uppgiftstilldelning.',
    'Task suppression is not permitted' => 'Borttagning av uppgift ej tillåten',
    'Changing assignee is not permitted' => 'Ändring av uppgiftstilldelning är inte tillåten',
    'Update only assigned tasks is permitted' => 'Endast ändring av tilldelade uppgifter tillåten',
    'Only for tasks assigned to the current user' => 'Endast för uppgifter tilldelade till nuvarande användare',
    'My projects' => 'Mina projekt',
    'You are not a member of any project.' => 'Du är inte medlem i något projekt.',
    'My subtasks' => 'Mina deluppgifter',
    '%d subtasks' => '%d deluppgifter',
    '%d subtask' => '%d deluppgift',
    'Only moving task between those columns is permitted for tasks assigned to the current user' => 'Endast förflyttning mellan dessa kolumner är tillåten för uppgifter som är tilldelade den nuvarande användaren',
    '[DUPLICATE]' => '[DUPLICERAD]',
    'DKK - Danish Krona' => 'DKK - Dansk krona',
    'Remove user from group' => 'Ta bort användare från grupp',
    'Assign the task to its creator' => 'Tilldela uppgiften till sin skapare',
    'This task was sent by email to "%s" with subject "%s".' => 'Uppgiften skickades per e-post till "%s" med titeln "%s".',
    'Predefined Email Subjects' => 'Fördefinierade e-postmottagare',
    'Write one subject by line.' => 'Skriv en titel per rad.',
    'Create another link' => 'Skapa ytterligare en länk',
    'BRL - Brazilian Real' => 'BRL - Brasiliansk real',
    'Add a new Kanboard task' => 'Skapa en ny Kanboard-uppgift',
    'Subtask not started' => 'Deluppgift ej påbörjad',
    'Subtask currently in progress' => 'Deluppgift pågående',
    'Subtask completed' => 'Deluppgift färdig',
    'Subtask added successfully.' => 'Deluppgift tillagd.',
    '%d subtasks added successfully.' => '%d deluppgifter tillagda.',
    'Enter one subtask by line.' => 'Skriv en deluppgift per rad.',
    'Predefined Contents' => 'Fördefinierat innehåll',
    'Predefined contents' => 'Fördefinierat innehåll',
    'Predefined Task Description' => 'Förderinierad uppgiftsbeskrivning',
    'Do you really want to remove this template? "%s"' => 'Vill du verkligen ta bort mallen "%s"?',
    'Add predefined task description' => 'Skapa fördefinierad uppgiftsbeskrivning',
    'Predefined Task Descriptions' => 'Fördefinierad uppgiftsbeskrivningar',
    'Template created successfully.' => 'Mallen skapades.',
    'Unable to create this template.' => 'Kunde inte skapa mallen.',
    'Template updated successfully.' => 'Mallen uppdaterades.',
    'Unable to update this template.' => 'Kunde inte uppdatera mallen.',
    'Template removed successfully.' => 'Mallen togs bort.',
    'Unable to remove this template.' => 'Kunde inte ta bort mallen.',
    'Template for the task description' => 'Mall för uppgiftsbeskrivning',
    'The start date is greater than the end date' => 'Startdatum är senare än slutdatum',
    'Tags must be separated by a comma' => 'Märkningar måste vara kommaseparerade',
    'Only the task title is required' => 'Endast märkningens titel krävs',
    'Creator Username' => 'Skapares användarnamn',
    'Color Name' => 'Färgnamn',
    'Column Name' => 'Kolumnnamn',
    'Swimlane Name' => 'Simbanans namn',
    'Time Estimated' => 'Estimerad tid',
    'Time Spent' => 'Spenderad tid',
    'External Link' => 'Extern länk',
    'This feature enables the iCal feed, RSS feed and the public board view.' => 'Denna funktion aktiverar iCal-flöde, RSS-flöde, samt offentlig tavelvy.',
    'Stop the timer of all subtasks when moving a task to another column' => 'Stoppa timern för samtliga deluppgifter när en uppgift flyttas till en annan kolumn',
    'Subtask Title' => 'Deluppgiftstitel',
    'Add a subtask and activate the timer when moving a task to another column' => 'Lägg till en deluppgift och aktivera timern när en uppgift flyttas till en annan kolumn',
    'days' => 'dagar',
    'minutes' => 'minuter',
    'seconds' => 'sekunder',
    'Assign automatically a color when preset start date is reached' => 'Tilldela automatiskt en färg när förvalt startdatum infaller',
    'Move the task to another column once a predefined start date is reached' => 'Flytta uppgiften till en annan kolumn när ett fördefinierat startdatum infaller',
    'This task is now linked to the task %s with the relation "%s"' => 'Denna uppgift är nu länkad till uppgiften "%s" via relationen "%s"',
    'The link with the relation "%s" to the task %s has been removed' => 'Länken med relationen "%s" till uppgiften "%s" har tagits bort',
    'Custom Filter:' => 'Anpassat filter:',
    'Unable to find this group.' => 'Kunde inte hitta gruppen.',
    '%s moved the task #%d to the column "%s"' => '%s flyttade uppgift #%d till kolumnen "%s"',
    '%s moved the task #%d to the position %d in the column "%s"' => '%s flyttade uppgift #%d till till position %d i kolumnen "%s"',
    '%s moved the task #%d to the swimlane "%s"' => '%s flyttade uppgift #%d till simbanan "%s"',
    '%sh spent' => '%stim. förbrukat',
    '%sh estimated' => '%stim. uppskattat',
    'Select All' => 'Välj alla',
    'Unselect All' => 'Avmarkera alla',
    'Apply action' => 'Genomför åtgärd',
    'Move selected tasks to another column or swimlane' => 'Flytta markerade uppgifter till en annan kolumn',
    'Edit tasks in bulk' => 'Massredigera uppgifer',
    'Choose the properties that you would like to change for the selected tasks.' => 'Välj vilka egenskaper som du vill ändra för de valda uppgifterna.',
    'Configure this project' => 'Konfigurera projekt',
    'Start now' => 'Börja nu',
    '%s removed a file from the task #%d' => '%s tog bort en fil från uppgift #%d',
    'Attachment removed from task #%d: %s' => 'Bilaga borttagen från uppgift #%d: %s',
    'No color' => 'Ingen färg',
    'Attachment removed "%s"' => 'Bilaga "%s" borttagen',
    '%s removed a file from the task %s' => '%s tog bort en fil från uppgiften %s',
    'Move the task to another swimlane when assigned to a user' => 'Flytta uppgiften till en annan simbana när den tilldelas en användare',
    'Destination swimlane' => 'Destinationssimbana',
    'Assign a category when the task is moved to a specific swimlane' => 'Tilldela en kategori när uppgiften flyttas till en specifik simbana',
    'Move the task to another swimlane when the category is changed' => 'Flytta uppgiften till en annan simbana när kategorin ändras',
    'Reorder this column by priority (ASC)' => 'Ändra ordning i denna kolumnen enligt prioritet (stigande)',
    'Reorder this column by priority (DESC)' => 'Ändra ordning i denna kolumnen enligt prioritet (fallande)',
    'Reorder this column by assignee and priority (ASC)' => 'Ändra ordning i denna kolumnen enligt tilldelning och prioritet (stigande)',
    'Reorder this column by assignee and priority (DESC)' => 'Ändra ordning i denna kolumnen enligt tilldelning och prioritet (fallande)',
    'Reorder this column by assignee (A-Z)' => 'Ändra ordning i denna kolumnen enligt tilldelning (A-Z)',
    'Reorder this column by assignee (Z-A)' => 'Ändra ordning i denna kolumnen enligt tilldelning (Z-A)',
    'Reorder this column by due date (ASC)' => 'Ändra ordning i denna kolumnen enligt förfallodatum (stigande)',
    'Reorder this column by due date (DESC)' => 'Ändra ordning i denna kolumnen enligt förfallodatum (fallande)',
    'Reorder this column by id (ASC)' => 'Sortera denna kolumn efter ID (stigande)',
    'Reorder this column by id (DESC)' => 'Sortera denna kolumn efter ID (fallande)',
    '%s moved the task #%d "%s" to the project "%s"' => '%s flyttade uppgift #%d "%s" till projektet "%s"',
    'Task #%d "%s" has been moved to the project "%s"' => 'Uppgift #%d "%s" har flyttats till projektet "%s"',
    'Move the task to another column when the due date is less than a certain number of days' => 'Flytta uppgiften till en annan kolumn när förfallodatum är närmare än ett visst antal dagar',
    'Automatically update the start date when the task is moved away from a specific column' => 'Uppdatera startdatum automatiskt när en uppgift flyttas från en specifik kolumn',
    'HTTP Client:' => 'HTTP-klient;',
    'Assigned' => 'Tilldelad',
    'Task limits apply to each swimlane individually' => 'Uppgiftsbegränsningar tillämpas på varje simbana individuellt',
    'Column task limits apply to each swimlane individually' => 'Kolumners uppgiftsbegränsning tillämpas på varje simbana individuellt',
    'Column task limits are applied to each swimlane individually' => 'Kolumners uppgiftsbegränsning tillämpas på varje simbana individuellt',
    'Column task limits are applied across swimlanes' => 'Kolumners uppgiftsbegränsning tillämpas över simbanor',
    'Task limit: ' => 'Uppgiftsgräns: ',
    'Change to global tag' => 'Ändra till global märkning',
    'Do you really want to make the tag "%s" global?' => 'Vill du verkligen göra märkningen "%s" global?',
    'Enable global tags for this project' => 'Aktivera global märkning för detta projekt',
    'Group membership(s):' => 'Gruppmedlemskap:',
    '%s is a member of the following group(s): %s' => '%s är medlem i följande grupp(er): %s',
    '%d/%d group(s) shown' => '%d/%d grupp(er) visade',
    'Subtask creation or modification' => 'Delupupgifts skapande eller ändrande',
    'Assign the task to a specific user when the task is moved to a specific swimlane' => 'Tilldela uppgiften till en viss användare när uppgiften flyttas till en viss swimlane',
    'Comment' => 'Kommentar',
    'Collapse vertically' => 'Fäll ihop vertikalt',
    'Expand vertically' => 'Fäll ut vertikalt',
    'MXN - Mexican Peso' => 'MXN - Mexikansk peso',
    'Estimated vs actual time per column' => 'Uppskattad kontra faktisk tid per kolumn',
    'HUF - Hungarian Forint' => 'HUF - Ungersk forint',
    'XBT - Bitcoin' => 'XBT – Bitcoin',
    'You must select a file to upload as your avatar!' => 'Du måste välja en fil att uppladda som din avatar!',
    'The file you uploaded is not a valid image! (Only *.gif, *.jpg, *.jpeg and *.png are allowed!)' => 'Filen du laddade upp är inte ett giltigt bildformat! (Endast *.gif *.jpg *.jpeg samt *.png är tillåtet!)',
    'Automatically set the due date when the task is moved away from a specific column' => 'Ställ automatiskt in förfallodatum när uppgiften flyttas från en specifik kolumn',
    'No other projects found.' => 'Inga andra projekt hittades.',
    'Tasks copied successfully.' => 'Uppgifter kopierades framgångsrikt.',
    'Unable to copy tasks.' => 'Det gick inte att kopiera uppgifter.',
    'Theme' => 'Tema',
    'Theme:' => 'Tema:',
    'Light theme' => 'Ljust tema',
    'Dark theme' => 'Mörkt tema',
    'Automatic theme - Sync with system' => 'Automatiskt tema – synkronisera med systemet',
    'Application managers or more' => 'Applikationsansvariga eller högre',
    'Administrators' => 'Administratörer',
    'Visibility:' => 'Synlighet:',
    'Standard users' => 'Standardanvändare',
    'Visibility is required' => 'Synlighet krävs',
    'The visibility should be an app role' => 'Synligheten bör vara en applikationsroll',
    'Reply' => 'Svara',
    '%s wrote: ' => '%s skrev: ',
    'Number of visible tasks in this column and swimlane' => 'Antal synliga uppgifter i denna kolumn och simlinje',
    'Number of tasks in this swimlane' => 'Antal uppgifter i denna simlinje',
    'Unable to find another subtask in progress, you can close this window.' => 'Kunde inte hitta en annan deluppgift i gång, du kan stänga detta fönster.',
    'This theme is invalid' => 'Detta tema är ogiltigt',
    'This role is invalid' => 'Denna roll är ogiltig',
    'This timezone is invalid' => 'Denna tidszon är ogiltig',
    'This language is invalid' => 'Detta språk är ogiltigt',
    'This URL is invalid' => 'Denna URL är ogiltig',
    'Date format invalid' => 'Ogiltigt datumformat',
    'Time format invalid' => 'Ogiltigt tidsformat',
    'Invalid Mail transport' => 'Ogiltig e-posttransport',
    'Color invalid' => 'Ogiltig färg',
    'This value must be greater or equal to %d' => 'Detta värde måste vara större än eller lika med %d',
    'Add a BOM at the beginning of the file (required for Microsoft Excel)' => 'Lägg till en BOM i början av filen (krävs för Microsoft Excel)',
    'Just add these tag(s)' => 'Lägg bara till dessa taggar',
    'Remove internal link(s)' => 'Ta bort interna länkar',
    'Import tasks from another project' => 'Importera uppgifter från ett annat projekt',
    'Select the project to copy tasks from' => 'Välj projektet att kopiera uppgifter från',
    'The total maximum allowed attachments size is %sB.' => 'Den totala maximalt tillåtna bilagestorleken är %sB.',
    'Add attachments' => 'Lägg till bilagor',
    'Task #%d "%s" is overdue' => 'Uppgift #%d "%s" är försenad',
    'Enable notifications by default for all new users' => 'Aktivera notifieringar som standard för alla nya användare',
];
